/* jshint globalstrict:true */
'use strict';

const OVERLAY_TEMPLATES_TEXT_COLORS_CONTAINER_ID = 'locrmaps-overlay-templates-text-colors';

/**
 * @param {HTMLSelectElement} select
 */
function trySettingOverlayTemplateTextColor(select) {
    if (!(select.options[select.selectedIndex] instanceof HTMLOptionElement)) {
        return;
    }
    if (!wp || !wp.hooks) {
        window.console.warn('trySettingOverlayTemplateTextColor: wp.hooks is not available');
        return;
    }

    const selectioOption = select.options[select.selectedIndex];
    wp.hooks.doAction( 'locrMAPSForWooCommerceSetOverlayTemplateTextColor', { value: selectioOption.value || 'black' } );
}

document.addEventListener('DOMContentLoaded', function() {
    const overlayTemplatesTextColorsElement = document.getElementById(OVERLAY_TEMPLATES_TEXT_COLORS_CONTAINER_ID);
    if (overlayTemplatesTextColorsElement instanceof HTMLSelectElement) {
        overlayTemplatesTextColorsElement.addEventListener('change', function(event) {
            if (!(event.target instanceof HTMLSelectElement)) {
                return;
            }

            trySettingOverlayTemplateTextColor(event.target);
        });

        if (overlayTemplatesTextColorsElement.value) {
            trySettingOverlayTemplateTextColor(overlayTemplatesTextColorsElement);

            wp?.hooks?.addAction(
                'locrMAPSInitialized',
                'locr/locrmaps',
                () => trySettingOverlayTemplateTextColor(overlayTemplatesTextColorsElement)
            );
        }
    }
});
